From: Stephen Rothwell <sfr@canb•auug.org.au>
To: Christian Brauner <brauner@kernel•org>,
Chuck Lever <chuck.lever@oracle•com>
Cc: Benjamin Coddington <bcodding@redhat•com>,
Linux Kernel Mailing List <linux-kernel@vger•kernel.org>,
Linux Next Mailing List <linux-next@vger•kernel.org>,
Mike Snitzer <snitzer@kernel•org>
Subject: linux-next: manual merge of the vfs-brauner tree with the nfsd tree
Date: Thu, 24 Oct 2024 08:15:15 +1100 [thread overview]
Message-ID: <20241024081515.1cd254a0@canb.auug.org.au> (raw)
[-- Attachment #1: Type: text/plain, Size: 1993 bytes --]
Hi all,
Today's linux-next merge of the vfs-brauner tree got a conflict in:
include/linux/exportfs.h
between commit:
6e99e4b4291e ("nfsd: disallow file locking and delegations for NFSv4 reexport")
from the nfsd tree and commit:
b875bd5b381e ("exportfs: Remove EXPORT_OP_ASYNC_LOCK")
from the vfs-brauner tree.
I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging. You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.
--
Cheers,
Stephen Rothwell
diff --cc include/linux/exportfs.h
index 106fd590d323,4cc8801e50e3..000000000000
--- a/include/linux/exportfs.h
+++ b/include/linux/exportfs.h
@@@ -251,32 -263,6 +264,19 @@@ struct export_operations
unsigned long flags;
};
- /**
- * exportfs_lock_op_is_async() - export op supports async lock operation
- * @export_ops: the nfs export operations to check
- *
- * Returns true if the nfs export_operations structure has
- * EXPORT_OP_ASYNC_LOCK in their flags set
- */
- static inline bool
- exportfs_lock_op_is_async(const struct export_operations *export_ops)
- {
- return export_ops->flags & EXPORT_OP_ASYNC_LOCK;
- }
-
+/**
+ * exportfs_lock_op_is_unsupported() - export does not support file locking
+ * @export_ops: the nfs export operations to check
+ *
+ * Returns true if the nfs export_operations structure has
+ * EXPORT_OP_NOLOCKSUPPORT in their flags set
+ */
+static inline bool
+exportfs_lock_op_is_unsupported(const struct export_operations *export_ops)
+{
+ return export_ops->flags & EXPORT_OP_NOLOCKSUPPORT;
+}
+
extern int exportfs_encode_inode_fh(struct inode *inode, struct fid *fid,
int *max_len, struct inode *parent,
int flags);
[-- Attachment #2: OpenPGP digital signature --]
[-- Type: application/pgp-signature, Size: 488 bytes --]
next reply other threads:[~2024-10-23 21:15 UTC|newest]
Thread overview: 12+ messages / expand[flat|nested] mbox.gz Atom feed top
2024-10-23 21:15 Stephen Rothwell [this message]
-- strict thread matches above, loose matches on Subject: below --
2026-05-28 14:28 linux-next: manual merge of the vfs-brauner tree with the nfsd tree Mark Brown
2026-05-28 14:51 ` Chuck Lever
2026-05-28 15:01 ` Mark Brown
2026-05-28 15:34 ` Chuck Lever
2025-11-16 20:34 Stephen Rothwell
2025-12-02 23:11 ` Stephen Rothwell
2024-02-07 0:41 Stephen Rothwell
2024-02-07 14:40 ` Chuck Lever
2024-02-07 14:58 ` Jeff Layton
2023-05-23 23:56 Stephen Rothwell
2023-05-24 9:08 ` Christian Brauner
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20241024081515.1cd254a0@canb.auug.org.au \
--to=sfr@canb$(echo .)auug.org.au \
--cc=bcodding@redhat$(echo .)com \
--cc=brauner@kernel$(echo .)org \
--cc=chuck.lever@oracle$(echo .)com \
--cc=linux-kernel@vger$(echo .)kernel.org \
--cc=linux-next@vger$(echo .)kernel.org \
--cc=snitzer@kernel$(echo .)org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox